<?php
/**
 * Plugin Name: Fluent Forms Emailable Verifier
 * Description: Integrates Emailable API for real-time email validation with Fluent Forms.
 * Version: 1.3.0
 * Author: WpScriptly
 */

if (!defined('ABSPATH')) exit;

// Register the admin settings for the API key and form ID
function ff_emailable_register_settings() {
    add_option('emailable_api_key', '');
    add_option('ff_emailable_form_id', ''); // Add form ID option
    register_setting('ff_emailable_options_group', 'emailable_api_key', 'sanitize_text_field');
    register_setting('ff_emailable_options_group', 'ff_emailable_form_id', 'sanitize_text_field'); // Register form ID
}
add_action('admin_init', 'ff_emailable_register_settings');

// Create a settings page for the Emailable API key, form ID, and How-to-Use section
function ff_emailable_register_options_page() {
    add_options_page('Emailable Settings', 'Emailable Settings', 'manage_options', 'ff-emailable', 'ff_emailable_options_page');
}
add_action('admin_menu', 'ff_emailable_register_options_page');

// Enqueue custom styles for the admin page
function ff_emailable_admin_styles() {
    echo '<style>
        .ff-emailable-wrapper {
            background-color: #f9f9f9;
            border: 1px solid #ddd;
            padding: 20px;
            width:800px;
            margin: 0 auto;
            border-radius: 5px;
        }
        .ff-emailable-wrapper h2 {
            font-size: 24px;
            margin-bottom: 15px;
            color: #333;
        }
        .ff-emailable-wrapper table {
            width: 100%;
        }
        .ff-emailable-wrapper th {
            text-align: left;
            padding-right: 10px;
        }
        .ff-emailable-wrapper td {
            padding: 8px 0;
        }
        .ff-emailable-how-to-use {
            margin-top: 30px;
            background-color: #eef4fc;
            padding: 15px;
            border: 1px solid #c3d3e5;
            border-radius: 5px;
        }
        .ff-emailable-how-to-use h3 {
            margin-top: 0;
            color: #1e73be;
        }
        .ff-emailable-how-to-use p {
            margin: 0;
            font-size: 14px;
        }
    </style>';
}
add_action('admin_head', 'ff_emailable_admin_styles');

// Admin options page structure
function ff_emailable_options_page() {
    ?>
    <div class="ff-emailable-wrapper">
        <h2>Emailable API Settings</h2>
        <form method="post" action="options.php">
            <?php settings_fields('ff_emailable_options_group'); ?>
            <table>
                <tr valign="top">
                    <th scope="row"><label for="emailable_api_key">Emailable API Key</label></th>
                    <td><input type="text" id="emailable_api_key" name="emailable_api_key" value="<?php echo get_option('emailable_api_key'); ?>" style="width: 100%;" /></td>
                </tr>
                <tr valign="top">
                    <th scope="row"><label for="ff_emailable_form_id">Target Fluent Form ID</label></th>
                    <td><input type="text" id="ff_emailable_form_id" name="ff_emailable_form_id" value="<?php echo get_option('ff_emailable_form_id'); ?>" style="width: 100%;" /></td>
                </tr>
            </table>
            <?php submit_button(); ?>
        </form>

        <div class="ff-emailable-how-to-use">
            <h3>How to Use</h3>
            <p><strong>1.</strong> Enter your <strong>Emailable API Key</strong> in the first input field.</p>
            <p><strong>2.</strong> Enter the <strong>Form ID</strong> of the Fluent Form you want to validate using the Emailable service in the second input field.</p>
            <p><strong>3.</strong> Click <strong>Save Changes</strong> to store the settings.</p>
            <p><strong>4.</strong> Ensure that your Fluent Form contains an <strong>email field</strong> with the name <code>email</code> or adjust the validation field in the plugin code.</p>
        </div>
    </div>
    <?php
}

// Hook into Fluent Forms submission to validate email
add_action('fluentform_before_insert_submission', 'ff_emailable_validate_email', 10, 3);

function ff_emailable_validate_email($insertData, $data, $form) {
    // Get the target form ID from the admin settings
    $target_form_id = get_option('ff_emailable_form_id');

    // If form ID is not set or doesn't match the submitted form, return early
    if (!$target_form_id || $form->id != $target_form_id) {
        return $insertData;
    }

    $email_field_name = 'email'; // Update this if your email field has a different name

    if (isset($data[$email_field_name])) {
        $email = sanitize_email($data[$email_field_name]);
        $api_key = get_option('emailable_api_key');

        // Call Emailable API
        $response = wp_remote_get("https://api.emailable.com/v1/verify?email={$email}&api_key={$api_key}");
        if (is_wp_error($response)) {
            $error_message = $response->get_error_message();
            wp_die('Something went wrong: ' . $error_message);
        }

        $body = json_decode(wp_remote_retrieve_body($response), true);

        // Check the state from Emailable's response
        if (isset($body['state']) && $body['state'] === 'deliverable') {
            return $insertData; // Email is valid, proceed with the submission
        } else {
            wp_die('The email address you provided is not valid. Please enter a valid email address.');
        }
    }

    return $insertData;
}
